export const isNumberLetter: (raw?: string) => boolean;
export const textJoin: (...parts: string[]) => string;
export const parseCookie: <T extends Record<string, string>>(value?: string) => T;
export interface CookieAttribute {
    domain?: string;
    path?: string;
    expires?: Date;
    'max-age'?: number;
    samesite?: 'lax' | 'strict' | 'none';
    secure?: boolean;
    partitioned?: boolean;
}
export function setCookie(key: string, value: string, attributes?: CookieAttribute): string;
export const parseLanguageHeader: (value: string) => string[];
export type TranslationResolver<T extends Record<string, any> = any> = (data: T) => string;
export type TranslationResolverData<T> = T extends TranslationResolver ? Parameters<T>[0] : never;
export type TranslationMap<T extends string> = {
    [key in T]: string | TranslationResolver;
};
export type TranslationConfiguration<N extends string, K extends string> = Record<N, TranslationMap<K> | (() => Promise<{
    default: TranslationMap<K>;
}>)>;
export class TranslationModel<Name extends string, Key extends string> {
    configuration: TranslationConfiguration<Name, Key>;
    loading: boolean;
    defaultLanguage: Name;
    currentLanguage: Name;
    currentMap: TranslationMap<Key>;
    get defaultMap(): TranslationMap<Key>;
    constructor(configuration: TranslationConfiguration<Name, Key>);
    onLanguageChange(handler: (language: Name) => any): void;
    protected setLanguage(name: Name): void;
    changeLanguage(name: Name): Promise<TranslationMap<Key>>;
    loadLanguages(names: string[]): Promise<TranslationMap<Key>>;
    textOf<K extends Key>(key: K, data?: TranslationResolverData<TranslationMap<Key>[K]>): string;
    t: <K extends Key>(key: K, data?: TranslationResolverData<TranslationMap<Key>[K]>) => string;
}

//# sourceMappingURL=index.d.ts.map
